# Topsis-Sidak-102003649

## What is Topsis?

Technique for Order Preference by Similarity to Ideal Solution (Topsis) originated in the 1980s as a multi-criteria decision making method.
Topsis chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution.

## Installation

```pip install Topsis-Sidak-102003649```


## License
© 2023 Sidak Khotra

This repository is licensed under the MIT license. See LICENSE for details.